package VMOMI::HostSystemPowerState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
